@@ -16,7 +16,7 @@ class queue:
     #Action: gives the object representation of the Queue
     #Output: the aforementioned object represenation
     def __repr__(self):     #object representation of object
-        return self.list    #return the list
+        return self.__str__()    #return the string representation
 
     #Input: value to enqueue
     #Action: adds that to the queue
@@ -40,6 +40,7 @@ class node:
     #Action: initialize the node
     #Output: None
     def __init__(self, tree, value, parent=None):
+        self.value = value
         self.tree = tree #initialize tree
         self.parent = parent    #initialize prent
         self.children = []  #initialize children
@@ -54,20 +55,17 @@ class node:
     #Action: gives the object representation of the node
     #Output: the aforementioned object represenation
     def ___repr__(self):
-        return {"Tree":str(self.tree), "Value":str(self.value)}
+        return self.__str__()   #return string representation
 
     #Input: value to change node to
     #Action: changes value and passes that change to every child
     #Output: nothing
     def set(self, value):
         self.value = value #change value
-        if children != []:  #if it has children
+        if self.children != []:  #if it has children
             for child in children:  #for every child
                 child.set_parent(self)  #set the child's parent to this
-        try:
-                self.tree.heapify() #try to heapify if it's in a heap
-        except: #just a normal tree:
-                self.tree.update()  #update tree
+        self.tree.update()
 
     #Input: parent node to change to
     #Action: changes parent node and recusively fixes tree
@@ -77,16 +75,13 @@ class node:
         if children != []:  #if it has children
             for child in children:  #for every child
                 child.set_parent(self)  #set the child's parent to this
-        try:
-                self.tree.heapify() #try to heapify if it's in a heap
-        except: #just a normal tree:
-                self.tree.update()  #update tree
+        self.tree.update()
 
     #Input: same for __init__ function (see above) but no parent or tree
     #Action: creates child
     #Output: nothing
     def add_child(self, value):
-        children.append(node(self.tree, value, self))   #add a child node
+        self.children.append(node(self.tree, value, self))   #add a child node
         try:
                 self.tree.heapify() #try to heapify if it's in a heap
         except: #just a normal tree:
@@ -96,12 +91,9 @@ class node:
     #Action: remove child
     #Output: nothing
     def remove_child(child):
-        if isinstance(child, node) and child in children:   #if it truly is a node and a child of this node
-            children.remove(child)  #remove child
-            try:
-                self.tree.heapify() #try to heapify if it's in a heap
-            except: #just a normal tree:
-                self.tree.update()  #update tree
+        if isinstance(child, node) and child in self.children:   #if it truly is a node and a child of this node
+            self.children.remove(child)  #remove child
+            self.tree.update()
         elif not isinstance(child, node):   #not a node
             raise TypeError("Not a node")
         else:   #it's not a child of this node
@@ -117,11 +109,16 @@ class tree:
         self.base = node(self, base)    #initialize base node
         self.nodes = [[base]]   #list of nodes. the index in the list is their layer in the tree, with the highest being the leaves, and 0 being the base node
 
+    def __str__(self):  #string representation
+        return f"Tree(base node={self.base.value}, depth={str(len(self.nodes))})"
+
+    def __repr__(self): #object representation
+        return self.__str__()   #return string representation
+
     #Input: optional new base node
     #Action: updates the tree
     #Output: nothing
-    def update(self, base=self.base):
-        self.base = base #set base
+    def update(self):
         self.nodes = [[self.base]]   #start new nodes list
         next_node = self.base   #set next node to base
         #get depth:
